@@ -789,7 +789,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		return $isActive;
 	}
 	/**
-	 * アクセスポイントが有効状態を更新
+	 * アクセスポイントの有効状態を更新
 	 *
 	 * @param int   $deviceType デバイスタイプ(0=PC,1=携帯,2=スマートフォン)
 	 * @param bool  $status		有効状態
@@ -812,7 +812,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		
 		$ret = $this->db->getPageIdRecord(0/*アクセスポイント*/, $pageId, $row);
 		if ($ret){
-			$ret = $this->db->updatePageId(0/*アクセスポイント*/, $pageId, $row['pg_name'], $row['pg_description'], $row['pg_priority'], $status, $row['pg_available']);
+			$ret = $this->db->updatePageId(0/*アクセスポイント*/, $pageId, $row['pg_name'], $row['pg_description'], $row['pg_priority'], $status, $row['pg_visible']);
 		}
 		return $ret;
 	}
