@@ -186,7 +186,7 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 		$imageTag = '';
 		if ($this->showImage){
 			$titleStr = $fetchedRow['be_name'];
-			$imageUrl = $this->gatImageUrl($entryId, $this->imageType);
+			$imageUrl = $this->getImageUrl($entryId, $this->imageType);
 			$style = '';
 			if ($this->imageWidth > 0) $style .= 'width:' . $this->imageWidth . 'px;';
 			if ($this->imageHeight > 0) $style .= 'height:' . $this->imageHeight . 'px;';
@@ -194,11 +194,13 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 			$imageTag = '<img src="' . $this->getUrl($imageUrl) . '" alt="' . $titleStr . '" title="' . $titleStr . '" ' . $style . '/>';
 			$imageTag = '<div style="float:left;"><a href="' . $escapedLinkUrl . '">' . $imageTag . '</a></div>';
 		}
+		// 記事名
+		$nameTag = '<a href="' . $escapedLinkUrl . '"><span>' . $this->convertToDispString($title) . '</span></a>';
+		$nameTag .= $optionStr;
+		if ($this->showImage) $nameTag = '<div class="clearfix">' . $nameTag . '</div>';
 		
 		$row = array(
-			'link_url' => $escapedLinkUrl,		// リンク
-			'name' => $this->convertToDispString($title),			// タイトル
-			'option'	=> $optionStr,								// オプション項目
+			'name' 		=> $nameTag,			// タイトル
 			'image'		=> $imageTag								// 画像
 		);
 		$this->tmpl->addVars('itemlist', $row);
@@ -214,7 +216,7 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 	 * @param string $format		画像フォーマット
 	 * @return string				URL
 	 */
-	function gatImageUrl($entryId, $format)
+	function getImageUrl($entryId, $format)
 	{
 		$filename = $this->gInstance->getImageManager()->getThumbFilename($entryId, $format);
 		$path = $this->gInstance->getImageManager()->getSystemThumbPath(M3_VIEW_TYPE_BLOG, 0/*PC用*/, $filename);
